# Development notes
This document contains notes that is intended for developers.

## Basic information
The development is mostly based on python 3.9. Backward capabilities are partially tested to python version 3.7.

## Note 2024/06/12